# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12role_service.proto\x1a\x1cgoogle/protobuf/struct.proto"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"U\n\x0fGetUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08"I\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"P\n\nUserInList\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08"3\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList"T\n\x13\x43reatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\'\n\x06policy\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct""\n\x14\x43reatePolicyResponse\x12\n\n\x02id\x18\x01 \x01(\t"`\n\x13UpdatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\'\n\x06policy\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"\x16\n\x14UpdatePolicyResponse"7\n\x13\x44\x65letePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"\x16\n\x14\x44\x65letePolicyResponse"4\n\x10GetPolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"<\n\x11GetPolicyResponse\x12\'\n\x06policy\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"K\n\x14GetPolicyListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"@\n\x15GetPolicyListResponse\x12\'\n\x06policy\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct"T\n\x12\x43heckAccessRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12(\n\x07inquiry\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct")\n\x13\x43heckAccessResponse\x12\x12\n\nhas_access\x18\x01 \x01(\x08\x32\xd8\x03\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponse\x12;\n\x0c\x43reatePolicy\x12\x14.CreatePolicyRequest\x1a\x15.CreatePolicyResponse\x12;\n\x0cUpdatePolicy\x12\x14.UpdatePolicyRequest\x1a\x15.UpdatePolicyResponse\x12;\n\x0c\x44\x65letePolicy\x12\x14.DeletePolicyRequest\x1a\x15.DeletePolicyResponse\x12\x32\n\tGetPolicy\x12\x11.GetPolicyRequest\x1a\x12.GetPolicyResponse\x12>\n\rGetPolicyList\x12\x15.GetPolicyListRequest\x1a\x16.GetPolicyListResponse\x12\x38\n\x0b\x43heckAccess\x12\x13.CheckAccessRequest\x1a\x14.CheckAccessResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "role_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _GETUSERREQUEST._serialized_start = 52
    _GETUSERREQUEST._serialized_end = 102
    _GETUSERRESPONSE._serialized_start = 104
    _GETUSERRESPONSE._serialized_end = 189
    _GETUSERLISTREQUEST._serialized_start = 191
    _GETUSERLISTREQUEST._serialized_end = 264
    _USERINLIST._serialized_start = 266
    _USERINLIST._serialized_end = 346
    _GETUSERLISTRESPONSE._serialized_start = 348
    _GETUSERLISTRESPONSE._serialized_end = 399
    _CREATEPOLICYREQUEST._serialized_start = 401
    _CREATEPOLICYREQUEST._serialized_end = 485
    _CREATEPOLICYRESPONSE._serialized_start = 487
    _CREATEPOLICYRESPONSE._serialized_end = 521
    _UPDATEPOLICYREQUEST._serialized_start = 523
    _UPDATEPOLICYREQUEST._serialized_end = 619
    _UPDATEPOLICYRESPONSE._serialized_start = 621
    _UPDATEPOLICYRESPONSE._serialized_end = 643
    _DELETEPOLICYREQUEST._serialized_start = 645
    _DELETEPOLICYREQUEST._serialized_end = 700
    _DELETEPOLICYRESPONSE._serialized_start = 702
    _DELETEPOLICYRESPONSE._serialized_end = 724
    _GETPOLICYREQUEST._serialized_start = 726
    _GETPOLICYREQUEST._serialized_end = 778
    _GETPOLICYRESPONSE._serialized_start = 780
    _GETPOLICYRESPONSE._serialized_end = 840
    _GETPOLICYLISTREQUEST._serialized_start = 842
    _GETPOLICYLISTREQUEST._serialized_end = 917
    _GETPOLICYLISTRESPONSE._serialized_start = 919
    _GETPOLICYLISTRESPONSE._serialized_end = 983
    _CHECKACCESSREQUEST._serialized_start = 985
    _CHECKACCESSREQUEST._serialized_end = 1069
    _CHECKACCESSRESPONSE._serialized_start = 1071
    _CHECKACCESSRESPONSE._serialized_end = 1112
    _ADMINROLE._serialized_start = 1115
    _ADMINROLE._serialized_end = 1587
# @@protoc_insertion_point(module_scope)
